@@ -1,7 +1,8 @@
 <?php
 /**
  * Mahara: Electronic portfolio, weblog, resume builder and social networking
- * Copyright (C) 2006-2008 Catalyst IT Ltd (http://www.catalyst.net.nz)
+ * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
+ *                         http://wiki.mahara.org/Contributors
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +21,7 @@
  * @subpackage artefact-internal
  * @author     Catalyst IT Ltd
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
- * @copyright  (C) 2006-2008 Catalyst IT Ltd http://catalyst.net.nz
+ * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
  *
  */
 
@@ -56,14 +57,18 @@ $profilefields['email'] = array();
 $profilefields['email']['all'] = get_records_array('artefact_internal_profile_email', 'owner', $USER->get('id'));
 $profilefields['email']['validated'] = array();
 $profilefields['email']['unvalidated'] = array();
+$profilefields['email']['unsent'] = array();
 if ($profilefields['email']['all']) {
     foreach ($profilefields['email']['all'] as $email) {
         if ($email->verified) {
             $profilefields['email']['validated'][] = $email->email;
         }
-        else {
+        else if (!empty($email->key)) {
             $profilefields['email']['unvalidated'][] = $email->email;
         }
+        else {
+            $profilefields['email']['unsent'][] = $email->email;
+        }
 
         if ($email->principal) {
             $profilefields['email']['default'] = $email->email;
@@ -73,6 +78,19 @@ if ($profilefields['email']['all']) {
 
 $items = array();
 foreach ( $element_list as $element => $type ) {
+    if ($type == 'wysiwyg' && isset($lockedfields[$element]) && !$USER->get('admin')) {
+        // TinyMCE ignores the disabled attribute on the textarea, so just turn it
+        // into an html element instead.
+        $items[$element] = array(
+            'type'  => 'html',
+            'title' => get_string($element, 'artefact.internal'),
+        );
+        if (isset($profilefields[$element])) {
+            $items[$element]['value'] = clean_html($profilefields[$element]);
+        }
+        continue;
+    }
+
     $items[$element] = array(
         'type'  => $type,
         'title' => get_string($element, 'artefact.internal'),
@@ -80,11 +98,11 @@ foreach ( $element_list as $element => $type ) {
 
     if ($type == 'wysiwyg') {
         $items[$element]['rows'] = 10;
-        $items[$element]['cols'] = 60;
+        $items[$element]['cols'] = 50;
     }
     if ($type == 'textarea') {
         $items[$element]['rows'] = 4;
-        $items[$element]['cols'] = 60;
+        $items[$element]['cols'] = 50;
     }
     if ($element == 'country') {
         $items[$element]['options'] = getoptions_country();
@@ -144,6 +162,10 @@ $elements = array(
         'class' => $fieldset != 'general' ? 'collapsed' : '',
         'elements' => $items
     ),
+    'fs' => array(
+        'type' => 'hidden',
+        'value' => $fieldset,
+    ),
     'submit' => array(
         'type'  => 'submitcancel',
         'value' => array(get_string('saveprofile','artefact.internal'), get_string('viewmyprofile', 'artefact.internal')),
@@ -158,6 +180,7 @@ $profileform = pieform(array(
     // will be uncommented when js for tabbed interface is called again after form submit
     //'jsform'     => true,
     'method'     => 'post',
+    'renderer'   => 'table',  // don't change unless you also modify profile.js to not require tables.
     'elements'   => $elements,
     'autofocus'  => false,
 ));
@@ -167,7 +190,7 @@ function get_desired_fields(&$allfields, $desiredfields, $section) {
     $return = array();
     $return["{$section}description"] = array(
         'type'  => 'html',
-        'labelhtml' => ($section == 'about') ? '<div id="profileicon"><a href="' . get_config('wwwroot') . 'artefact/internal/profileicons.php"><img src="' . get_config('wwwroot') . 'thumb.php?type=profileiconbyid&maxsize=100&id=' . intval($USER->get('profileicon')) . '" alt=""></a></div>' : '',
+        'labelhtml' => ($section == 'about') ? '<div id="profileicon"><a href="' . get_config('wwwroot') . 'artefact/file/profileicons.php"><img src="' . get_config('wwwroot') . 'thumb.php?type=profileiconbyid&maxsize=100&id=' . intval($USER->get('profileicon')) . '" alt=""></a></div>' : '',
         'value' => get_string("{$section}description", 'artefact.internal')
     );
     foreach ($desiredfields as $field) {
@@ -190,10 +213,16 @@ function profileform_validate(Pieform $form, $values) {
         $form->set_error('email', get_string('primaryemailinvalid'));
     }
 
-    if (isset($values['email']['unvalidated']) && is_array($values['email']['validated'])) {
-        foreach ($values['email']['unvalidated'] as $email) {
-            if (record_exists('artefact_internal_profile_email', 'email', $email)) {
+    if (isset($values['email']['unsent']) && is_array($values['email']['validated'])) {
+        require_once('phpmailer/class.phpmailer.php');
+        foreach ($values['email']['unsent'] as $email) {
+            if (!PHPMailer::ValidateAddress($email)) {
+                $form->set_error('email', get_string('invalidemailaddress', 'artefact.internal') . ': ' . hsc($email));
+                break;
+            }
+            else if (record_exists('artefact_internal_profile_email', 'email', $email)) {
                 $form->set_error('email', get_string('unvalidatedemailalreadytaken', 'artefact.internal'));
+                break;
             }
         }
     }
@@ -219,11 +248,11 @@ function profileform_submit(Pieform $form, $values) {
         }
 
         if ($element == 'email') {
-            if (!isset($values['email']['unvalidated'])) {
-                $values['email']['unvalidated'] = array();
+            if (!isset($values['email']['unsent'])) {
+                $values['email']['unsent'] = array();
             }
             // find new addresses
-            foreach ($values['email']['unvalidated'] as $email) {
+            foreach ($values['email']['unsent'] as $email) {
                 if (
                     in_array($email, $profilefields['email']['validated'])
                     || in_array($email, $profilefields['email']['unvalidated'])
@@ -331,13 +360,17 @@ function profileform_submit(Pieform $form, $values) {
                         'id' => $USER->get('id'),
                     )
                 );
+                $USER->email = $values['email']['default'];
+                $USER->commit();
             }
         }
         else {
-            $classname = generate_artefact_class_name($element);
-            $profile = new $classname(0, array('owner' => $USER->get('id')));
-            $profile->set('title', $values[$element]);
-            $profile->commit();
+            if (!isset($profilefields[$element]) || $values[$element] != $profilefields[$element]) {
+                $classname = generate_artefact_class_name($element);
+                $profile = new $classname(0, array('owner' => $USER->get('id')));
+                $profile->set('title', $values[$element]);
+                $profile->commit();
+            }
         }
     }
 
@@ -388,7 +421,7 @@ $smarty = smarty(array('artefact/internal/js/profile.js'), array(), array(
 
 
 $smarty->assign('profileform', $profileform);
-$smarty->assign('heading', get_string('editprofile', 'artefact.internal'));
+$smarty->assign('PAGEHEADING', hsc(get_string('editprofile', 'artefact.internal')));
 $smarty->display('artefact:internal:index.tpl');
 
 
