@@ -1,7 +1,8 @@
 <?php
 /**
  * Mahara: Electronic portfolio, weblog, resume builder and social networking
- * Copyright (C) 2006-2008 Catalyst IT Ltd (http://www.catalyst.net.nz)
+ * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
+ *                         http://wiki.mahara.org/Contributors
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +21,7 @@
  * @subpackage lang
  * @author     Catalyst IT Ltd
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
- * @copyright  (C) 2006-2008 Catalyst IT Ltd http://catalyst.net.nz
+ * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
  *
  */
 
@@ -30,8 +31,8 @@ $string['administration'] = 'Administration';
 
 // Installer
 $string['installation'] = 'Installation';
-$string['release'] = 'Release %s (%s)';
-$string['copyright'] = 'Copyright &copy; 2006 onwards, Catalyst IT Ltd';
+$string['release'] = 'version %s (%s)';
+$string['copyright'] = 'Copyright &copy; 2006 onwards, <a href="http://wiki.mahara.org/Contributors">Catalyst IT Ltd and others</a>';
 $string['agreelicense'] = 'I agree';
 $string['component'] = 'Component or plugin';
 $string['continue'] = 'Continue';
@@ -41,12 +42,15 @@ $string['fromversion'] = 'From version';
 $string['information'] = 'Information';
 $string['installsuccess'] = 'Successfully installed version ';
 $string['toversion'] =  'To version';
+$string['localdatasuccess'] = 'Successfully installed local customisations';
 $string['notinstalled'] = 'Not installed';
 $string['nothingtoupgrade'] = 'Nothing to upgrade';
-$string['performinginstallsandupgrades'] = 'Performing installs and upgrades...';
+$string['performinginstallation'] = 'Performing installation...';
+$string['performingupgrades'] = 'Performing upgrades...';
 $string['runupgrade'] = 'Run upgrade';
 $string['successfullyinstalled'] = 'Successfully installed Mahara!';
 $string['thefollowingupgradesareready'] = 'The following upgrades are ready:';
+$string['registerthismaharasite'] = 'Register this Mahara site';
 $string['upgradeloading'] = 'Loading...';
 $string['upgrades'] = 'Upgrades';
 $string['upgradesuccess'] = 'Successfully upgraded';
@@ -55,6 +59,9 @@ $string['upgradefailure'] = 'Failed to upgrade!';
 $string['noupgrades'] = 'Nothing to upgrade! You are fully up to date!';
 $string['youcanupgrade'] = 'You can upgrade Mahara from %s (%s) to %s (%s)!';
 $string['Plugin'] = 'Plugin';
+$string['jsrequiredforupgrade'] = 'You must enable javascript to perform an install or upgrade.';
+$string['dbnotutf8warning'] = 'You are not using a UTF-8 database. Mahara stores all data as UTF-8 internally. You may still attempt this upgrade but it is recommended that you convert your database to UTF-8.';
+$string['dbcollationmismatch'] = 'A column of your database is using a collation that is not the same as the database default.  Please ensure all columns use the same collation as the database.';
 
 // Admin navigation menu
 $string['adminhome']      = 'Admin home';
@@ -70,8 +77,10 @@ $string['editsitepages']     = 'Edit site pages';
 $string['editsitepagesdescription'] = 'Edit the content of various pages around the site';
 $string['linksandresourcesmenu'] = 'Links and Resources Menu';
 $string['linksandresourcesmenudescription'] = 'Manage the links and files within the Links and Resources Menu';
-$string['adminfiles']          = 'Admin Files';
-$string['adminfilesdescription'] = 'Upload and administer files that can be put in the Links and Resources Menu';
+$string['sitefiles']          = 'Site Files';
+$string['sitefilesdescription'] = 'Upload and administer files that can be put in the Links and Resources Menu and in Site Views';
+$string['siteviews']          = 'Site Views';
+$string['siteviewsdescription'] = 'Create and administer Views and View Templates for the entire site';
 $string['networking']          = 'Networking';
 $string['networkingdescription'] = 'Configure networking for Mahara';
 
@@ -94,29 +103,80 @@ $string['usersearchinstructions'] = 'You can search for users by clicking on the
 $string['institutionmembersdescription'] = 'Associate users with institutions';
 $string['institutionstaffdescription'] = 'Assign users Staff permissions';
 $string['institutionadminsdescription'] = 'Assign Institution Administrator access rights';
+$string['institutionviews']          = 'Institution Views';
+$string['institutionviewsdescription'] = 'Create and administer Views and View Templates for an Institution';
+$string['institutionfiles']          = 'Institution Files';
+$string['institutionfilesdescription'] = 'Upload and manage files for use in Institution Views';
 
 $string['pluginadmin'] = 'Plugin Administration';
 $string['pluginadmindescription'] = 'Install and configure plugins';
 
+$string['htmlfilters'] = 'HTML Filters';
+$string['htmlfiltersdescription'] = 'Enable new filters for HTML Purifier';
+$string['newfiltersdescription'] = 'If you have downloaded a new set of HTML filters, you can install them by unzipping the file into the folder %s and then clicking the button below';
+$string['filtersinstalled'] = 'Filters installed.';
+$string['nofiltersinstalled'] = 'No html filters installed.';
+
+// Register your Mahara
+$string['Field'] = 'Field';
+$string['Value'] = 'Value';
+$string['datathatwillbesent'] = 'Data that will be sent';
+$string['sendweeklyupdates'] = 'Send weekly updates?';
+$string['sendweeklyupdatesdescription'] = 'If checked, your site will send weekly updates to mahara.org with some statistics about your site';
+$string['Register'] = 'Register';
+$string['registrationfailedtrylater'] = 'Registation failed with error code %s. Please try again later.';
+$string['registrationsuccessfulthanksforregistering'] = 'Registation successful - thanks for registering!';
+$string['registeryourmaharasite'] = 'Register your Mahara Site';
+$string['registeryourmaharasitedetail'] = '
+<p>You can choose to register your Mahara Site with <a href="http://mahara.org/">mahara.org</a>. Registration is free, and helps us build up a picture of the Mahara installation base around the world.</p>
+<p>You can see the information that will be sent to mahara.org - nothing that can personally identify any of your users will be sent.</p>
+<p>If you tick &quot;send weekly updates&quot;, Mahara will automatically send an update to mahara.org once a week with your updated information.</p>
+<p>Registering will remove this notice. You will be able to change whether you send weekly updates on the <a href="%sadmin/site/options.php">site options</a> page.</p>';
+
+// Close site
+$string['Close'] = 'Close';
+$string['closesite'] = 'Close Site';
+$string['closesitedetail'] = 'You may close the site to everyone except administrators.  This will be useful when preparing for a database upgrade.  Only administrators will be able to log in until you either reopen the site, or an upgrade is successfully completed.';
+$string['Open'] = 'Open';
+$string['reopensite'] = 'Reopen Site';
+$string['reopensitedetail'] = 'Your site is closed.  Site administrators may stay logged in until an upgrade is detected.';
+
 // Site options
+$string['adminsonly'] = 'Administrators only';
+$string['adminsandstaffonly'] = 'Administrators and Staff only';
 $string['allowpublicviews'] = 'Allow public views';
-$string['allowpublicviewsdescription'] = 'If set to yes, users will be able to create Views that are accessable to the public rather than only to logged in users';
+$string['allowpublicviewsdescription'] = 'If set to yes, users will be able to create portfolio Views that are accessable to the public rather than only to logged in users';
+$string['allowpublicprofiles'] = 'Allow public profiles';
+$string['allowpublicprofilesdescription'] = 'If set to yes, users will be able to set their profile Views to be accessable to the public rather than only to logged in users';
+$string['captchaonregisterform'] = 'Captcha required for registration';
+$string['captchaonregisterformdescription'] = 'Require users to type letters from a captcha image when submitting the registration form';
+$string['captchaoncontactform'] = 'Captcha required for contact us';
+$string['captchaoncontactformdescription'] = 'Require logged-out users to type letters from a captcha image when submitting the Contact Us form';
 $string['defaultaccountinactiveexpire'] = 'Default account inactivity time';
 $string['defaultaccountinactiveexpiredescription'] = 'How long a user account will remain active without the user logging in';
 $string['defaultaccountinactivewarn'] = 'Warning time for inactivity/expiry';
 $string['defaultaccountinactivewarndescription'] = 'The time before user accounts are to expire or become inactive at which a warning message will be sent to them';
 $string['defaultaccountlifetime'] = 'Default account lifetime';
 $string['defaultaccountlifetimedescription'] = 'If set, user accounts will expire after this period of time from when they have been created';
+$string['embeddedcontent'] = 'Embedded content';
+$string['embeddedcontentdescription'] = 'If you would like users to be able to embed videos or other outside content into their portfolios, you can choose which sites to trust below.';
+$string['Everyone'] = 'Everyone';
+$string['institutionautosuspend'] = 'Auto-suspend expired institutions';
+$string['institutionautosuspenddescription'] = 'If checked, expired institutions will be automatically suspended';
+$string['institutionexpirynotification'] = 'Warning time for institution expiry';
+$string['institutionexpirynotificationdescription'] = 'A notification message will be sent to site and institutional admins the long before a site expires';
 $string['language'] = 'Language';
 $string['pathtoclam'] = 'Path to clam';
 $string['pathtoclamdescription'] = 'The filesystem path to clamscan or clamdscan';
-$string['pathtofile'] = 'Path to file';
-$string['pathtofiledescription'] = 'Filesystem path to the \'file\' program';
 $string['searchplugin'] = 'Search plugin';
 $string['searchplugindescription'] = 'Search plugin to use';
 $string['sessionlifetime'] = 'Session lifetime';
 $string['sessionlifetimedescription'] = 'Time in minutes after which an inactive logged in user will be automatically logged out';
 $string['setsiteoptionsfailed'] = 'Failed setting the %s option';
+$string['showselfsearchsideblock'] = 'Enable Portfolio Search';
+$string['showselfsearchsideblockdescription'] = 'Display the "Search My Portfolio" side block in the My Portfolio section of the site';
+$string['showtagssideblock'] = 'Enable Tag Cloud';
+$string['showtagssideblockdescription'] = 'If enabled, users will see a side block in the My Portfolio section of the site with a list of their most frequently used tags';
 $string['sitedefault'] = 'Site Default';
 $string['sitelanguagedescription'] = 'The default language for the site';
 $string['sitename'] = 'Site name';
@@ -124,13 +184,20 @@ $string['sitenamedescription'] = 'The site name appears in certain places around
 $string['siteoptionspagedescription'] = 'Here you can set some global options that will apply by default throughout the entire site.';
 $string['siteoptionsset'] = 'Site options have been updated.';
 $string['sitethemedescription'] = 'The default theme for the site';
+$string['tagssideblockmaxtags'] = 'Maximum Tags in Cloud';
+$string['tagssideblockmaxtagsdescription'] = 'The default number of tags to display in user tag clouds';
 $string['theme'] = 'Theme';
+$string['trustedsites'] = 'Trusted sites';
 $string['updatesiteoptions'] = 'Update site options';
 $string['usersallowedmultipleinstitutions'] = 'Users allowed multiple institutions';
 $string['usersallowedmultipleinstitutionsdescription'] = 'If checked, users can be members of several institutions at the same time';
-$string['usersseenewthemeonlogin'] = 'Users will see the new theme the next time they log in.';
+$string['usersseenewthemeonlogin'] = 'Other users will see the new theme the next time they log in.';
 $string['viruschecking'] = 'Virus checking';
 $string['viruscheckingdescription'] = 'If checked, virus checking will be enabled for all uploaded files using ClamAV';
+$string['whocancreategroups'] = 'Who can create Groups';
+$string['whocancreategroupsdescription'] = 'Which users will be able to create new groups';
+$string['whocancreatepublicgroups'] = 'Who can create Public Groups';
+$string['whocancreatepublicgroupsdescription'] = 'Which users will be able to make groups that are viewable by the general public';
 
 // Site content
 $string['about']               = 'About';
@@ -150,7 +217,7 @@ $string['termsandconditions']  = 'Terms and Conditions';
 $string['uploadcopyright']     = 'Upload Copyright Statement';
 
 // Links and resources menu editor
-$string['adminfile']           = 'Admin file';
+$string['sitefile']            = 'Site file';
 $string['adminpublicdirname']  = 'public';  // Name of the directory in which to store public admin files
 $string['adminpublicdirdescription'] = 'Files accessible by logged out users';
 $string['badmenuitemtype']     = 'Unknown item type';
@@ -169,7 +236,7 @@ $string['menuitemdeleted']     = 'Item deleted';
 $string['menuitemsaved']       = 'Item saved';
 $string['menuitemsloaded']     = 'Items loaded';
 $string['name']                = 'Name';
-$string['noadminfiles']        = 'No admin files available';
+$string['nositefiles']         = 'No site files available';
 $string['public']              = 'public';
 $string['savingmenuitem']      = 'Saving item';
 $string['type']                = 'Type';
@@ -194,17 +261,30 @@ $string['promiscuousmodeenabled'] = 'Auto-register has been enabled. ';
 $string['promiscuousmodedescription'] = 'Create an institution record for any host that connects to you, and allow its users to log on to Mahara';
 $string['wwwroot'] = 'WWW Root';
 $string['wwwrootdescription'] = 'This is the URL at which your users access this Mahara installation, and the URL the SSL keys are generated for';
+$string['proxysettings'] = 'Proxy settings';
+$string['proxyaddress'] = 'Proxy address';
+$string['proxyaddressdescription'] = 'If your site uses a proxy server to access the internet, specify the proxies in <em>hostname:portnumber</em> notation';
+$string['proxyaddressset'] = 'Proxy address set';
+$string['proxyauthmodel'] = 'Proxy authenticated model';
+$string['proxyauthmodeldescription'] = 'Select your proxy\'s authentication model, if appropriate';
+$string['proxyauthmodelset'] = 'Proxy authentication model has been set';
+$string['proxyauthcredentials'] = 'Proxy credentials';
+$string['proxyauthcredentialsdescription'] = 'Enter the credentials required for your proxy to authenticate your web server in <em>username:password</em> format';
+$string['proxyauthcredntialsset'] = 'Proxy authentication credentials set';
 
-// Upload CSV
+
+// Upload CSV and CSV errors
 $string['csvfile'] = 'CSV File';
 $string['emailusersaboutnewaccount'] = 'E-mail users about their account?';
 $string['emailusersaboutnewaccountdescription'] = 'Whether an e-mail should be sent to users informing them of their new account details';
 $string['forceuserstochangepassword'] = 'Force password change?';
 $string['forceuserstochangepassworddescription'] = 'Whether users should be forced to change their password when they log in for the first time';
 $string['uploadcsvinstitution'] = 'The institution and authentication method for the new users';
-$string['uploadcsvconfigureauthplugin'] = 'You must configure an authentication plugin before you can add users by CSV';
+$string['configureauthplugin'] = 'You must configure an authentication plugin before you can add users';
 $string['csvfiledescription'] = 'The file containing users to add';
-$string['uploadcsverrorinvalidfieldname'] = 'The field name "%s" is invalid';
+$string['csverroremptyfile'] = 'The csv file is empty.';
+$string['invalidfilename'] = 'The file "%s" does not exist';
+$string['uploadcsverrorinvalidfieldname'] = 'The field name "%s" is invalid, or you have more fields than your header row specifies';
 $string['uploadcsverrorrequiredfieldnotspecified'] = 'A required field "%s" has not been specified in the format line';
 $string['uploadcsverrornorecords'] = 'The file appears to contain no records (although the header is fine)';
 $string['uploadcsverrorunspecifiedproblem'] = 'The records in your CSV file could not be inserted for some reason. If your file is in the correct format then this is a bug and you should <a href="https://eduforge.org/tracker/?func=add&group_id=176&atid=739">create a bug report</a>, attaching the CSV file (remember to blank out passwords!) and, if possible, the error log file';
@@ -259,6 +339,7 @@ $string['staffusersupdated'] = 'Staff users updated';
 
 // Suspended Users
 $string['deleteusers'] = 'Delete Users';
+$string['deleteuser'] = 'Delete User';
 $string['confirmdeleteusers'] = 'Are you sure you want to delete the selected users?';
 $string['exportingnotsupportedyet'] = 'Exporting user profiles is not supported yet';
 $string['exportuserprofiles'] = 'Export User Profiles';
@@ -283,10 +364,8 @@ $string['resetpassworddescription'] = 'If you enter text here, it will replace t
 $string['forcepasswordchange'] = 'Force password change on next login';
 $string['forcepasswordchangedescription'] = 'The user will be directed to a change password page the next time they login.';
 $string['sitestaff'] = 'Site Staff';
-$string['sitestaffdescription'] = 'If checked, the user can create controlled Communities, receive and release submitted views and access key user profile information.';
 $string['siteadmins'] = 'Site Admins';
-$string['siteadmin'] = 'Site administrator';
-$string['siteadmindescription'] = 'Site administrators can to do anything and go anywhere on the site';
+$string['siteadmin'] = 'Site Administrator';
 $string['accountexpiry'] = 'Account expires';
 $string['accountexpirydescription'] = 'Date on which the user\'s login is automatically disabled.';
 $string['suspended'] = 'Suspended';
@@ -295,16 +374,42 @@ $string['suspendedreasondescription'] = 'The text that will be displayed to the
 $string['unsuspenduser'] = 'Unsuspend User';
 $string['thisuserissuspended'] = 'This user has been suspended';
 $string['suspendedby'] = 'This user has been suspended by %s';
+$string['deleteuser'] = 'Delete User';
+$string['userdeletedsuccessfully'] = 'User deleted successfully';
+$string['confirmdeleteuser'] = 'Are you sure you want to delete this user?';
 $string['filequota'] = 'File quota (MB)';
 $string['filequotadescription'] = 'Total storage available in the user\'s files area.';
+$string['addusertoinstitution'] = 'Add User to Institution';
+$string['removeuserfrominstitution'] = 'Remove user from this institution';
 $string['confirmremoveuserfrominstitution'] = 'Are you sure you want to remove the user from this institution?';
+$string['usereditdescription'] = 'Here you can view and set details for this user account. Below, you can also <a href="#suspend">suspend or delete this account</a>, or change settings for this user in the <a href="#institutions">institutions they are in</a>.';
+$string['suspenddeleteuser'] = 'Suspend/Delete User';
+$string['suspenddeleteuserdescription'] = 'Here you may suspend or entirely delete a user account. Suspended users are unable to log in until their account is unsuspended. Please note that while a suspension can be undone, deletion <strong>cannot</strong> be undone.';
+$string['deleteusernote'] = 'Please note that this operation <strong>cannot be undone</strong>.';
+$string['youcannotadministerthisuser'] = 'You cannot administer this user';
 
 // Add User
 $string['adduser'] = 'Add User';
 $string['adduserdescription'] = 'Create a new user';
-$string['adduserpagedescription'] = '<p>Here you may add a new user to the system. Once added, they will be sent an e-mail informing them of their new account, including their username and password. They will be asked to change their password upon first log in.</p>';
+$string['basicinformationforthisuser'] = 'Basic information for this user.';
+$string['clickthebuttontocreatetheuser'] = 'Click the button to create the user.';
+$string['createnewuserfromscratch'] = 'Create new user from scratch';
 $string['createuser'] = 'Create User';
+$string['failedtoobtainuploadedleapfile'] = 'Failed to obtain the uploaded LEAP2A file';
+$string['failedtounzipleap2afile'] = 'Failed to unzip the LEAP2A file. Check the error log for more information';
+$string['fileisnotaziporxmlfile'] = 'This file has not been detected to be a zipfile or XML file';
+$string['howdoyouwanttocreatethisuser'] = 'How do you want to create this user?';
+$string['leap2aimportfailed'] = '<p><strong>Sorry - Importing the LEAP2A file failed.</strong></p><p>This could be because you did not select a valid LEAP2A file to upload. Alternatively, there may be a bug in Mahara causing your file to fail, even though it is valid.</p><p>Please <a href="add.php">go back and try again</a>, and if the problem persists, you may want to post to the <a href="http://mahara.org/forums/">Mahara Forums</a> to ask for help. Be prepared to be asked for a copy of your file!</p>';
 $string['newuseremailnotsent'] = 'Failed to send welcome email to new user.';
+$string['newusercreated'] = 'New user account created successfully';
+$string['noleap2axmlfiledetected'] = 'No leap2a.xml file detected - please check your export file again';
+$string['Or...'] = 'Or...';
+$string['userwillreceiveemailandhastochangepassword'] = 'They will receive an e-mail informing them of their new account details. On first log in, they will be forced to change their password.';
+$string['uploadleap2afile'] = 'Upload LEAP2A File';
+
+$string['usercreationmethod'] = '1 - User Creation Method';
+$string['basicdetails'] = '2 - Basic Details';
+$string['create'] = '3 - Create';
 
 // Login as
 $string['loginasuser'] = 'Login as %s';
@@ -330,16 +435,19 @@ $string['adminnoauthpluginforinstitution'] = 'Please configure an authentication
 $string['institutionname'] = 'Institution name';
 $string['institutionnamealreadytaken'] = 'This institution name is already taken';
 $string['institutiondisplayname'] = 'Institution display name';
+$string['institutionexpiry'] = 'Institution expiry date';
+$string['institutionexpirydescription'] = 'The date at which this institutions membership of %s will be suspended.';
 $string['institutionupdatedsuccessfully'] = 'Institution updated successfully.';
 $string['registrationallowed'] = 'Registration allowed?';
-$string['registrationalloweddescription2'] = 'Whether users can register for your site for this institution using the registration form';
+$string['registrationalloweddescription2'] = 'Whether users can register for your site for this institution using the registration form.  If registration is off, non-members cannot request membership of the institution, and members cannot leave the institution or delete their user accounts voluntarily.';
 $string['defaultmembershipperiod'] = 'Default membership period';
 $string['defaultmembershipperioddescription'] = 'How long new members remain associated with the institution';
 $string['authenticatedby'] = 'Authentication Method';
-$string['authenticatedbydescription'] = '';
+$string['authenticatedbydescription'] = 'How this user authenticates to Mahara';
 $string['remoteusername'] = 'Username for external authentication';
-$string['remoteusernamedescription'] = 'If this user is authenticated by an external method and you would like to associate them with a different identity on a remote database, enter their remote username here.';
+$string['remoteusernamedescription'] = 'If this user signs in to %s from a remote site using the XMLRPC authentication plugin, this is the username which identifies the user on the remote site';
 $string['institutionsettings'] = 'Institution Settings';
+$string['institutionsettingsdescription'] = 'Here you can change settings regarding this user\'s membership with institutions in the system.';
 $string['changeinstitution'] = 'Change Institution';
 $string['institutionstaff'] = 'Institution Staff';
 $string['institutionadmins'] = 'Institution Administrators';
@@ -393,6 +501,7 @@ $string['institutionusersupdated_inviteUser'] = 'Invitations sent';
 
 $string['maxuseraccounts'] = 'Maximum User Accounts Allowed';
 $string['maxuseraccountsdescription'] = 'The maximum number of user accounts that can be associated with the institution.  If there is no limit, this field should be left blank.';
+$string['institutionmaxusersexceeded'] = 'This institution is full, you will have to increase the number of allowed users in this institution before this user can be added.';
 $string['institutionuserserrortoomanyusers'] = 'The users were not added.  The number of members cannot exceed the maximum allowed for the institution.  You can add fewer users, remove some users from the institution, or ask the site administrator to increase the maximum number of users.';
 $string['institutionuserserrortoomanyinvites'] = 'Your invitations were not sent.  The number of existing members plus the number of outstanding invitations cannot exceed the institution\'s maximum number of users.  You can invite fewer users, remove some users from the institution, or ask the site administrator to increase the maximum number of users.';
 
@@ -404,6 +513,21 @@ $string['Admins'] = 'Admins';
 $string['noinstitutions'] = 'No Institutions';
 $string['noinstitutionsdescription'] = 'If you would like to associate users with an institution, you should create the institution first.';
 
+$string['Lockedfields'] = 'Locked fields';
+
+// Suspend Institutions
+$string['errorwhileunsuspending'] = 'An error occured while trying to unsuspend';
+$string['institutionsuspended'] = 'Institution suspended';
+$string['institutionunsuspended'] = 'Institution unsuspended';
+$string['suspendedinstitution'] = 'SUSPENDED';
+$string['suspendinstitution'] = 'Suspend Institution';
+$string['suspendinstitutiondescription'] = 'Here you may suspend an institution. Users of suspended institutions will be unable to log in until the institution is unsuspended.';
+$string['suspendedinstitutionmessage'] = 'This institution has been suspended';
+$string['unsuspendinstitution'] = 'Unsuspend Institution';
+$string['unsuspendinstitutiondescription'] = 'Here you may unsuspend an institution. Users of suspended institutions will be unable to log in until the institution is unsuspended.<br /><strong>Beware:</strong> Unsuspending an institution without resetting or turning off its expiry date may result in a daily re-suspension.';
+$string['unsuspendinstitutiondescription_top'] = '<em>Beware:</em> Unsuspending an institution without resetting or turning off its expiry date may result in a daily re-suspension.';
+
+
 // Admin User Search
 $string['Query'] = 'Query';
 $string['Institution'] = 'Institution';
