@@ -1,7 +1,8 @@
 <?php
 /**
  * Mahara: Electronic portfolio, weblog, resume builder and social networking
- * Copyright (C) 2006-2008 Catalyst IT Ltd (http://www.catalyst.net.nz)
+ * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
+ *                         http://wiki.mahara.org/Contributors
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +21,7 @@
  * @subpackage lang
  * @author     Catalyst IT Ltd
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
- * @copyright  (C) 2006-2008 Catalyst IT Ltd http://catalyst.net.nz
+ * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
  *
  */
 
@@ -31,15 +32,18 @@ $string['phpversion'] = 'Mahara will not run on PHP < 5.1.3. Please upgrade your
 $string['jsonextensionnotloaded'] = 'Your server configuration does not include the JSON extension. Mahara requires this in order to send some data to and from the browser. Please make sure that it is loaded in php.ini, or install it if it is not installed.';
 $string['pgsqldbextensionnotloaded'] = 'Your server configuration does not include the pgsql extension. Mahara requires this in order to store data in a relational database. Please make sure that it is loaded in php.ini, or install it if it is not installed.';
 $string['mysqldbextensionnotloaded'] = 'Your server configuration does not include the mysql extension. Mahara requires this in order to store data in a relational database. Please make sure that it is loaded in php.ini, or install it if it is not installed.';
-$string['mysqldbtypedeprecated'] = 'You are using the dbtype "mysql" in your config file. Please change it to "mysql5" - "mysql" is deprecated.';
 $string['unknowndbtype'] = 'Your server configuration references an unknown database type. Valid values are "postgres8" and "mysql5". Please change the database type setting in config.php.';
+$string['domextensionnotloaded'] = 'Your server configuration does not include the dom extension. Mahara requires this in order to parse XML data from a variety of sources.';
 $string['xmlextensionnotloaded'] = 'Your server configuration does not include the %s extension. Mahara requires this in order to parse XML data from a variety of sources. Please make sure that it is loaded in php.ini, or install it if it is not installed.';
 $string['gdextensionnotloaded'] = 'Your server configuration does not include the gd extension. Mahara requires this in order to perform resizes and other operations on uploaded images. Please make sure that it is loaded in php.ini, or install it if it is not installed.';
+$string['gdfreetypenotloaded'] = 'Your server configuration of the gd extension does not include Freetype support. Mahara requires this to in order to build CAPTCHA images. Please make sure that gd is configured with it.';
 $string['sessionextensionnotloaded'] = 'Your server configuration does not include the session extension. Mahara requires this in order to support users logging in. Please make sure that it is loaded in php.ini, or install it if it is not installed.';
+$string['curllibrarynotinstalled'] = 'Your server configuration does not include the curl extension. Mahara requires this for Moodle integration and to retrieve external feeds. Please make sure that curl is loaded in php.ini, or install it if it is not installed.';
 $string['registerglobals'] = 'You have dangerous PHP settings, register_globals is on. Mahara is trying to work around this, but you should really fix it';
 $string['magicquotesgpc'] = 'You have dangerous PHP settings, magic_quotes_gpc is on. Mahara is trying to work around this, but you should really fix it';
 $string['magicquotesruntime'] = 'You have dangerous PHP settings, magic_quotes_runtime is on. Mahara is trying to work around this, but you should really fix it';
 $string['magicquotessybase'] = 'You have dangerous PHP settings, magic_quotes_sybase is on. Mahara is trying to work around this, but you should really fix it';
+$string['mimemagicnotloaded'] = 'Your server does not have the mime_magic extension enabled. Mahara may have trouble detecting file types.';
 
 $string['safemodeon'] = 'Your server appears to be running safe mode. Mahara does not support running in safe mode. You must turn this off in either the php.ini file, or in your apache config for the site.
 
@@ -55,10 +59,13 @@ $string['dbconnfailed'] = 'Mahara could not connect to the application database.
 
 The error received was:
 ';
+$string['dbnotutf8'] = 'You are not using a UTF-8 database. Mahara stores all data as UTF-8 internally. Please drop and re-create your database using UTF-8 encoding.';
+$string['dbversioncheckfailed'] = 'Your database server version is not new enough to successfully run Mahara. Your server is %s %s, but Mahara requires at least version %s.';
 
 // general exception error messages
 $string['blocktypenametaken'] = "Block type %s is already taken by another plugin (%s)";
 $string['artefacttypenametaken'] = "Artefact type %s is already taken by another plugin (%s)";
+$string['artefacttypemismatch'] = "Artefact type mismatch, you are trying to use this %s as a %s";
 $string['classmissing'] = "class %s for type %s in plugin %s was missing";
 $string['artefacttypeclassmissing'] = "Artefact types must all implement a class.  Missing %s";
 $string['artefactpluginmethodmissing'] =  "Artefact plugin %s must implement %s and doesn't";
@@ -68,13 +75,14 @@ $string['versionphpmissing'] = 'Plugin %s %s is missing version.php!';
 $string['blocktypeprovidedbyartefactnotinstallable'] = 'This will be installed as part of the installation of artefact plugin %s';
 $string['blockconfigdatacalledfromset'] = 'Configdata should not be set directly, use PluginBlocktype::instance_config_save instead';
 $string['invaliddirection'] = 'Invalid direction %s';
+$string['onlyoneprofileviewallowed'] = 'You are only allowed one profile view';
+$string['onlyoneblocktypeperview'] = 'Cannot put more than one %s blocktype into a view';
 
 // if you change these next two , be sure to change them in libroot/errors.php
 // as they are duplicated there, in the case that get_string was not available.
 $string['unrecoverableerror'] = 'A nonrecoverable error occurred.  This probably means that you have encountered a bug in the system.';
 $string['unrecoverableerrortitle'] = '%s - Site Unavailable';
 $string['parameterexception'] = 'A required parameter was missing';
-$string['accessdeniedexception'] = 'You do not have access to view this page';
 
 $string['notfound'] = 'Not Found';
 $string['notfoundexception'] = 'The page you are looking for could not be found';
@@ -85,6 +93,7 @@ $string['accessdeniedexception'] =  'You do not have access to view this page';
 $string['viewnotfoundexceptiontitle'] = 'View not found';
 $string['viewnotfoundexceptionmessage'] = 'You tried to access a view that didn\'t exist!';
 $string['viewnotfound'] = 'View with id %s not found';
+$string['youcannotviewthisusersprofile'] = 'You cannot view this user\'s profile';
 
 $string['artefactnotfoundmaybedeleted'] = "Artefact with id %s not found (maybe it has been deleted already?)";
 $string['artefactnotfound'] = 'Artefact with id %s not found';
