@@ -76,6 +76,12 @@ function ensure_sanity() {
     if (!extension_loaded('dom')) {
         throw new ConfigSanityException(get_string('domextensionnotloaded', 'error'));
     }
+    if (!function_exists('mime_content_type')) {
+        log_environ(get_string('mimemagicnotloaded', 'error'));
+        function mime_content_type($filename) {
+            return 'application/octet-stream';
+        }
+    }
 
     //Check for freetype in the gd extension
     $gd_info = gd_info();
@@ -310,8 +316,7 @@ function get_raw_string($identifier, $section='mahara') {
     // For a raw string we don't want to format any arguments using
     // sprintf, so the replace function passed to get_string_location
     // should just return the first argument and ignore the second.
-    return get_string_location($identifier, $section, array(), 
-                               create_function('$string, $args','return $string;'));
+    return get_string_location($identifier, $section, array(), 'raw_langstring');
 }
 
 
@@ -812,27 +817,44 @@ function print_object($mixed) {
  */
 function current_language() {
     global $USER, $CFG, $SESSION;
+
+    static $lang;
+
+    if (!empty($lang)) {
+        return $lang;
+    }
+
     if ($USER instanceof User) {
-        $lang = $USER->get_account_preference('lang');
-        if ($lang !== null && $lang != 'default') {
-            if (language_installed($lang)) {
-                return $lang;
+        $userlang = $USER->get_account_preference('lang');
+        if ($userlang !== null && $userlang != 'default') {
+            if (language_installed($userlang)) {
+                $lang = $userlang;
+            }
+            else {
+                $USER->set_account_preference('lang', 'default');
             }
-            $USER->set_account_preference('lang', 'default');
         }
     }
 
-    if (is_a($SESSION, 'Session')) {
+    if (empty($lang) && is_a($SESSION, 'Session')) {
         $sesslang = $SESSION->get('lang');
         if (!empty($sesslang) && $sesslang != 'default') {
-            return $sesslang;
+            $lang = $sesslang;
         }
     }
 
-    if (!empty($CFG->lang)) {
-        return $CFG->lang;
+    if (empty($lang)) {
+        $lang = !empty($CFG->lang) ? $CFG->lang : 'en.utf8';
     }
-    return 'en.utf8';
+
+    // Set locale.  We are probably being called from get_string_location.
+    // $lang had better be non-empty, or it will call us again.
+    if ($args = split(',', get_string_location('locales', 'langconfig', array(), 'raw_langstring', $lang))) {
+        array_unshift($args, LC_ALL);
+        call_user_func_array('setlocale', $args);
+    }
+
+    return $lang;
 }
 
 /**
@@ -846,6 +868,10 @@ function format_langstring($string,$args) {
     return call_user_func_array('sprintf',array_merge(array($string),$args));
 }
 
+function raw_langstring($string) {
+    return $string;
+}
+
 /**
  * Helper function to figure out whether an array is an array or a hash
  * @param array $array array to check
@@ -1319,12 +1345,12 @@ function pieform_configure() {
     );
 }
 
-function pieform_validate(Pieform $form, $values) {
+function form_validate($sesskey) {
     global $USER;
-    if (!isset($values['sesskey'])) {
+    if (is_null($sesskey)) {
         throw new UserException('No session key');
     }
-    if ($USER && $USER->is_logged_in() && $USER->get('sesskey') != $values['sesskey']) {
+    if ($USER && $USER->is_logged_in() && $USER->get('sesskey') != $sesskey) {
         throw new UserException('Invalid session key');
     }
 
@@ -1346,6 +1372,13 @@ function pieform_validate(Pieform $form, $values) {
     }
 }
 
+function pieform_validate(Pieform $form, $values) {
+    if (!isset($values['sesskey'])) {
+        throw new UserException('No session key');
+    }
+    form_validate($values['sesskey']);
+}
+
 function pieform_reply($code, $data) {
     global $SESSION;
     if (isset($data['message'])) {
