@@ -53,9 +53,19 @@ function pieform_rule_required_i18n() {/*{{{*/
         'ja.utf8' => array(
             'required' => 'このフィールドは、必須入力フィールドです。'
         ),
-	'es.utf8' => array(
-	    'required' => 'Este campo es obligatorio'
-	),
+        'es.utf8' => array(
+            'required' => 'Este campo es obligatorio'
+        ),
+        'sl.utf8' => array(
+            'required' => 'To polje je zahtevano'
+        ),
+        'nl.utf8' => array(
+            'required' => 'Dit veld is vereist'
+        ),
+        'cs.utf8' => array(
+            'required' => 'Povinné pole'
+        ),
+
     );
 }/*}}}*/
 
