@@ -1,7 +1,8 @@
 <?php
 /**
  * Mahara: Electronic portfolio, weblog, resume builder and social networking
- * Copyright (C) 2006-2008 Catalyst IT Ltd (http://www.catalyst.net.nz)
+ * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
+ *                         http://wiki.mahara.org/Contributors
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +21,7 @@
  * @subpackage core
  * @author     Catalyst IT Ltd
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
- * @copyright  (C) 2006-2008 Catalyst IT Ltd http://catalyst.net.nz
+ * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
  *
  */
 
@@ -115,8 +116,8 @@ function set_account_preference($userid, $field, $value) {
 
 /** 
  * Change language-specific stuff in the db for a user.  Currently
- * changes the name of the 'blogfiles', 'assessmentfiles'
- * folders in the user's files area and the views and artefacts tagged for the profile
+ * changes the name of the 'assessmentfiles' folder in the user's
+ * files area and the views and artefacts tagged for the profile
  * sideblock
  *
  * @param int $userid user id to set preference for
@@ -124,10 +125,6 @@ function set_account_preference($userid, $field, $value) {
  * @param string $newlang new language
  */
 function change_language($userid, $oldlang, $newlang) {
-    if (get_field('artefact_installed', 'active', 'name', 'blog')) {
-        safe_require('artefact', 'blog');
-        ArtefactTypeBlogPost::change_language($userid, $oldlang, $newlang);
-    }
     if (get_field('artefact_installed', 'active', 'name', 'file')) {
         safe_require('artefact', 'file');
         ArtefactTypeFolder::change_language($userid, $oldlang, $newlang);
@@ -204,6 +201,7 @@ function expected_account_preferences() {
                  'messages'       => 'allow',
                  'lang'           => 'default',
                  'addremovecolumns' => 0,
+                 'tagssideblockmaxtags' => get_config('tagssideblockmaxtags'),
                  );
 }
 
@@ -267,9 +265,13 @@ function get_profile_field($userid, $field) {
  * @param string $subject email subject
  * @param string $messagetext text version of email
  * @param string $messagehtml html version of email (will send both html and text)
+ * @param array  $customheaders email headers
  * @throws EmailException
  */ 
-function email_user($userto, $userfrom, $subject, $messagetext, $messagehtml='') {
+function email_user($userto, $userfrom, $subject, $messagetext, $messagehtml='', $customheaders=null) {
+    global $IDPJUMPURL;
+    static $mnetjumps = array();
+
     if (!get_config('sendemail')) {
         // You can entirely disable Mahara from sending any e-mail via the 
         // 'sendemail' configuration variable
@@ -280,6 +282,29 @@ function email_user($userto, $userfrom, $subject, $messagetext, $messagehtml='')
         throw new InvalidArgumentException("empty user given to email_user");
     }
     
+    // If the user is a remote xmlrpc user, trawl through the email text for URLs
+    // to our wwwroot and modify the url to direct the user's browser to login at
+    // their home site before hitting the link on this site
+    if (!empty($userto->mnethostwwwroot) && !empty($userto->mnethostapp)) {
+        require_once(get_config('docroot') . 'auth/xmlrpc/lib.php');
+
+        // Form the request url to hit the idp's jump.php
+        if (isset($mnetjumps[$userto->mnethostwwwroot])) {
+            $IDPJUMPURL = $mnetjumps[$userto->mnethostwwwroot];
+        } else {
+            $mnetjumps[$userto->mnethostwwwroot] = $IDPJUMPURL = PluginAuthXmlrpc::get_jump_url_prefix($userto->mnethostwwwroot, $userto->mnethostapp);
+        }
+
+        $wwwroot = get_config('wwwroot');
+        $messagetext = preg_replace_callback('%(' . $wwwroot . '([\w_:\?=#&@/;.~-]*))%',
+            'localurl_to_jumpurl',
+            $messagetext);
+        $messagehtml = preg_replace_callback('%href=["\'`](' . $wwwroot . '([\w_:\?=#&@/;.~-]*))["\'`]%',
+            'localurl_to_jumpurl',
+            $messagehtml);
+    }
+
+
     require_once('phpmailer/class.phpmailer.php');
 
     $mail = new phpmailer();
@@ -311,20 +336,36 @@ function email_user($userto, $userfrom, $subject, $messagetext, $messagehtml='')
         }
     }
 
-    if (empty($userfrom)) {
+    if (empty($userfrom) || $userfrom->email == get_config('noreplyaddress')) {
         $mail->Sender = get_config('noreplyaddress');
         $mail->From = $mail->Sender;
-        $mail->FromName = get_string('emailname');
+        $mail->FromName = (isset($userfrom->id)) ? display_name($userfrom, $userto) : get_config('sitename');
+        $customheaders[] = 'Precedence: Bulk'; // Try to avoid pesky out of office responses
+        $messagetext .= "\n\n" . get_string('pleasedonotreplytothismessage') . "\n";
+        if ($messagehtml) {
+            $messagehtml .= "\n\n<p>" . get_string('pleasedonotreplytothismessage') . "</p>\n";
+        }
     }
     else {
         $mail->Sender = $userfrom->email;
         $mail->From = $mail->Sender;
         $mail->FromName = display_name($userfrom, $userto);
     }
-           
-    $mail->AddReplyTo($mail->From, $mail->FromName);
+    $replytoset = false;
+    if (!empty($customheaders) && is_array($customheaders)) {
+        foreach ($customheaders as $customheader) {
+            $mail->AddCustomHeader($customheader);
+            if (0 === stripos($customheader, 'reply-to')) {
+                $replytoset = true;
+            }
+        }
+    }
 
-    $mail->Subject = substr(stripslashes($subject), 0, 78);
+    if (!$replytoset) {
+        $mail->AddReplyTo($mail->From, $mail->FromName);
+    }
+
+    $mail->Subject = substr(stripslashes($subject), 0, 900);
 
     if ($to = get_config('sendallemailto')) {
         // Admins can configure the system to send all email to a given address 
@@ -335,6 +376,7 @@ function email_user($userto, $userfrom, $subject, $messagetext, $messagehtml='')
         if ($messagehtml) {
             $messagehtml = '<p>' . hsc($notice) . '</p>' . $messagehtml;
         }
+        $usertoname = display_name($userto, $userto, true) . ' (' . get_string('divertingemailto', 'mahara', $to) . ')';
     }
     else {
         $usertoname = display_name($userto, $userto);
@@ -368,15 +410,18 @@ function email_user($userto, $userfrom, $subject, $messagetext, $messagehtml='')
  * Both parameters should be objects containing id, preferredname, firstname,
  * lastname, admin
  *
- * @param object the user that you're trying to format to a string
- * @param object the user that is looking at the string representation (if left
+ * @param object $user the user that you're trying to format to a string
+ * @param object $userto the user that is looking at the string representation (if left
  * blank, will default to the currently logged in user).
+ * @param boolean $nameonly do not append the user's username even if $userto can see it.
  *
  * @returns string name to display
  */
 function display_name($user, $userto=null, $nameonly=false) {
     global $USER;
-    
+    static $resultcache = array();
+    static $usercache   = array();
+
     if (empty($userto)) {
         $userto = new StdClass;
         $userto->id            = $USER->get('id');
@@ -387,11 +432,48 @@ function display_name($user, $userto=null, $nameonly=false) {
         $userto->admin         = $USER->get('admin') || $USER->is_institutional_admin();
         $userto->staff         = $USER->get('staff') || $USER->is_institutional_staff();
     }
+    else if (is_numeric($userto)) {
+        if (isset($usercache[$userto])) {
+            $userto = $usercache[$userto];
+        }
+        else if ($userto == $USER->get('id')) {
+            $userto = new StdClass;
+            $userto->id            = $USER->get('id');
+            $userto->username      = $USER->get('username');
+            $userto->preferredname = $USER->get('preferredname');
+            $userto->firstname     = $USER->get('firstname');
+            $userto->lastname      = $USER->get('lastname');
+            $userto->admin         = $USER->get('admin') || $USER->is_institutional_admin();
+            $userto->staff         = $USER->get('staff') || $USER->is_institutional_staff();
+            $usercache[$userto->id] = $userto;
+        }
+        else {
+            $userto = $usercache[$userto] = get_record('usr', 'id', $userto);
+        }
+    }
+
     if (is_array($user)) {
         $user = (object)$user;
     }
     else if (is_numeric($user)) {
-        $user = get_record('usr', 'id', $user);
+        if (isset($usercache[$user])) {
+            $user = $usercache[$user];
+        }
+        else if ($user == $USER->get('id')) {
+            $user = new StdClass;
+            $user->id            = $USER->get('id');
+            $user->username      = $USER->get('username');
+            $user->preferredname = $USER->get('preferredname');
+            $user->firstname     = $USER->get('firstname');
+            $user->lastname      = $USER->get('lastname');
+            $user->admin         = $USER->get('admin') || $USER->is_institutional_admin();
+            $user->staff         = $USER->get('staff') || $USER->is_institutional_staff();
+            $user->deleted       = 0;
+            $usercache[$user->id] = $user;
+        }
+        else {
+            $user = $usercache[$user] = get_record('usr', 'id', $user);
+        }
     }
     if (!is_object($user)) {
         throw new InvalidArgumentException("Invalid user passed to display_name");
@@ -407,34 +489,45 @@ function display_name($user, $userto=null, $nameonly=false) {
         $user->lastname      = $userObj->get('lastname');
         $user->admin         = $userObj->get('admin');
         $user->staff         = $userObj->get('staff');
+        $user->deleted       = $userObj->get('deleted');
+    }
+
+    $user->id   = (isset($user->id)) ? $user->id : null;
+    $userto->id = (isset($userto->id)) ? $userto->id : null;
+
+    if (isset($resultcache[$user->id][$userto->id][$nameonly])) {
+        return $resultcache[$user->id][$userto->id][$nameonly];
     }
 
     // if they don't have a preferred name set, just return here
+    $firstlast = (isset($user->deleted) && $user->deleted) ? get_string('deleteduser') : ($user->firstname . ' ' . $user->lastname);
     if (empty($user->preferredname)) {
         if ((!empty($userto->admin) || !empty($userto->staff)) && !$nameonly) {
-            return $user->firstname . ' ' . $user->lastname . ' (' . $user->username . ')';
+            return ($resultcache[$user->id][$userto->id][$nameonly] = $firstlast . ' (' . $user->username . ')');
         }
-        return $user->firstname . ' ' . $user->lastname;
+        return ($resultcache[$user->id][$userto->id][$nameonly] = $firstlast);
     }
     else if ($user->id == $userto->id) {
         // If viewing our own name, show it how we like it
-        return $user->preferredname;
+        return ($resultcache[$user->id][$userto->id][$nameonly] = $user->preferredname);
     }
 
     if ((!empty($userto->admin) || !empty($userto->staff)) && !$nameonly) {
-        return $user->preferredname . ' (' . $user->firstname . ' ' . $user->lastname . ' - ' . $user->username . ')';
+        return ($resultcache[$user->id][$userto->id][$nameonly]
+            = $user->preferredname . ' (' . $firstlast . ' - ' . $user->username . ')');
     }
 
-    $sql = 'SELECT g1.member
+    $sql = "SELECT g1.member
             FROM {group_member} g1 
             JOIN {group_member} g2
                 ON g1.group = g2.group
             JOIN {group} g ON (g.id = g1.group AND g.deleted = 0)
-            WHERE g1.member = ? AND g2.member = ? AND g2.tutor = ?';
-    if (record_exists_sql($sql, array($user->id, $userto->id, 1))) {
-        return $user->preferredname . ($nameonly ? '' : ' (' . $user->firstname . ' ' . $user->lastname . ')');
+            WHERE g1.member = ? AND g2.member = ? AND g2.role = 'tutor'";
+    if (record_exists_sql($sql, array($user->id, $userto->id))) {
+        return ($resultcache[$user->id][$userto->id][$nameonly]
+            = $user->preferredname . ($nameonly ? '' : ' (' . $firstlast . ')'));
     }
-    return  $user->preferredname;
+    return ($resultcache[$user->id][$userto->id][$nameonly] = $user->preferredname);
 }
 
 /**
@@ -625,7 +718,15 @@ function suspend_user($suspendeduserid, $reason, $suspendinguserid=null) {
     $message = new StdClass;
     $message->users = array($suspendeduserid);
     $message->subject = get_string_from_language($lang, 'youraccounthasbeensuspended');
-    $message->message = get_string_from_language($lang, 'youraccounthasbeensuspendedtext');
+    if ($reason == '') {
+        $message->message = get_string_from_language($lang, 'youraccounthasbeensuspendedtext2', 'mahara',
+            get_config('sitename'), display_name($suspendinguserid, $suspendeduserid));
+    }
+    else {
+        $message->message = get_string_from_language($lang, 'youraccounthasbeensuspendedreasontext', 'mahara',
+            get_config('sitename'), display_name($suspendinguserid, $suspendeduserid), $reason);
+    }
+    require_once('activity.php');
     activity_occurred('maharamessage', $message);
 
     handle_event('suspenduser', $suspendeduserid);
@@ -648,7 +749,8 @@ function unsuspend_user($userid) {
     $message = new StdClass;
     $message->users = array($userid);
     $message->subject = get_string_from_language($lang, 'youraccounthasbeenunsuspended');
-    $message->message = get_string_from_language($lang, 'youraccounthasbeenunsuspendedtext');
+    $message->message = get_string_from_language($lang, 'youraccounthasbeenunsuspendedtext2', 'mahara', get_config('sitename'));
+    require_once('activity.php');
     activity_occurred('maharamessage', $message);
 
     handle_event('unsuspenduser', $userid);
@@ -684,30 +786,21 @@ function delete_user($userid) {
 
     // Set authinstance to default internal, otherwise the old authinstance can be blocked from deletion
     // by deleted users.
-    $authinst = get_field('auth_instance', 'id', 'institution', 'mahara', 'instancename', 'internal');
+    $authinst = get_field('auth_instance', 'id', 'institution', 'mahara', 'authname', 'internal');
     if ($authinst) {
-        $deleterec->authinstance = $deleterec->lastauthinstance = $authinst;
+        $deleterec->authinstance = $authinst;
     }
 
     update_record('usr', $deleterec);
 
-    // Because the user is being deleted, but their email address may be wanted 
-    // for a new user, we change their email addresses to add 
-    // 'deleted.[timestamp]'
-    execute_sql('UPDATE {artefact_internal_profile_email}
-    SET email = email || ?
-    WHERE owner = ?', array($datasuffix, $userid));
-
-    // mark all groups the user owns as deleted
-    if ($groupids = get_column('group', 'id', 'owner', $userid)) {
-        require_once('group.php');
+    // Remove user from any groups they're in, invited to or want to be in
+    $groupids = get_column('group_member', '"group"', 'member', $userid);
+    if ($groupids) {
+        require_once(get_config('libroot') . 'group.php');
         foreach ($groupids as $groupid) {
-            delete_group($groupid);
+            group_remove_user($groupid, $userid, true);
         }
     }
-
-    // Remove user from any groups they're in, invited to or want to be in
-    delete_records('group_member', 'member', $userid);
     delete_records('group_member_request', 'member', $userid);
     delete_records('group_member_invite', 'member', $userid);
 
@@ -719,8 +812,39 @@ function delete_user($userid) {
         WHERE owner = ?
         OR requester = ?', array($userid, $userid));
 
-    // Remove remote user records
+    delete_records('artefact_access_usr', 'usr', $userid);
     delete_records('auth_remote_user', 'localusr', $userid);
+    delete_records('import_queue', 'usr', $userid);
+    delete_records('usr_account_preference', 'usr', $userid);
+    delete_records('usr_activity_preference', 'usr', $userid);
+    delete_records('usr_infectedupload', 'usr', $userid);
+    delete_records('usr_institution', 'usr', $userid);
+    delete_records('usr_institution_request', 'usr', $userid);
+    delete_records('usr_password_request', 'usr', $userid);
+    delete_records('usr_watchlist_view', 'usr', $userid);
+    delete_records('view_access_usr', 'usr', $userid);
+
+    // Remove the user's views & artefacts
+    $viewids = get_column('view', 'id', 'owner', $userid);
+    if ($viewids) {
+        require_once(get_config('libroot') . 'view.php');
+        foreach ($viewids as $viewid) {
+            $view = new View($viewid);
+            $view->delete();
+        }
+    }
+    $artefactids = get_column('artefact', 'id', 'owner', $userid);
+    if ($artefactids) {
+        foreach ($artefactids as $artefactid) {
+            try {
+                $a = artefact_instance_from_id($artefactid);
+                $a->delete();
+            }
+            catch (ArtefactNotFoundException $e) {
+                // Awesome, it's already gone.
+            }
+        }
+    }
 
     db_commit();
 
@@ -813,7 +937,8 @@ function send_user_message($to, $message, $from=null) {
     }
 
     $messagepref = get_account_preference($to->id, 'messages');
-    if ((is_friend($from->id, $to->id) && $messagepref == 'friends') || $messagepref == 'allow' || $from->get('admin')) {
+    if ($messagepref == 'allow' || ($messagepref == 'friends' && is_friend($from->id, $to->id)) || $from->get('admin')) {
+        require_once('activity.php');
         activity_occurred('usermessage', 
             array(
                 'userto'   => $to->id, 
@@ -834,6 +959,9 @@ function send_user_message($to, $message, $from=null) {
  * @return boolean whether userfrom is allowed to send messages to userto
  */
 function can_send_message($from, $to) {
+    if (empty($from)) {
+        return false; // not logged in
+    }
 	if (!is_object($from)) {
 	    $from = get_record('usr', 'id', $from);
 	}
@@ -848,11 +976,11 @@ function can_send_message($from, $to) {
 }
 
 function load_user_institutions($userid) {
-    if (empty($userid)) {
+    if (!is_numeric($userid) || $userid < 0) {
         throw new InvalidArgumentException("couldn't load institutions, no user id specified");
     }
     if ($institutions = get_records_sql_assoc('
-        SELECT u.institution,'.db_format_tsfield('ctime').','.db_format_tsfield('expiry').',u.studentid,u.staff,u.admin,i.theme
+        SELECT u.institution,'.db_format_tsfield('ctime').','.db_format_tsfield('u.expiry', 'membership_expiry').',u.studentid,u.staff,u.admin,i.theme,i.registerallowed
         FROM {usr_institution} u INNER JOIN {institution} i ON u.institution = i.name
         WHERE u.usr = ?', array($userid))) {
         return $institutions;
@@ -868,10 +996,11 @@ function load_user_institutions($userid) {
  */
 function get_new_username($desired) {
     $maxlen = 30;
-    $desired = substr($desired, 0, $maxlen);
+    $desired = strtolower(substr($desired, 0, $maxlen));
     $taken = get_column_sql('
         SELECT username FROM {usr}
-        WHERE username ' . db_ilike() . " '" . substr($desired, 0, $maxlen - 6) . "%'");
+        WHERE username ' . db_ilike() . " ?",
+        array(substr($desired, 0, $maxlen - 6) . '%'));
     if (!$taken) {
         return $desired;
     }
@@ -890,7 +1019,7 @@ function get_new_username($desired) {
  * @param $userlist the ids separated by commas
  * @return array containing the users in the order from $userlist
  */
-function get_users_data($userlist) {
+function get_users_data($userlist, $getviews=true) {
 	global $USER;
     $sql = 'SELECT u.id, 0 AS pending,
                 COALESCE((SELECT ap.value FROM {usr_account_preference} ap WHERE ap.usr = u.id AND ap.field = \'messages\'), \'allow\') AS messages,
@@ -898,7 +1027,7 @@ function get_users_data($userlist) {
                 (SELECT 1 FROM {usr_friend} WHERE ((usr1 = ? AND usr2 = u.id) OR (usr2 = ? AND usr1 = u.id))) AS friend,
                 (SELECT 1 FROM {usr_friend_request} fr WHERE fr.requester = ? AND fr.owner = u.id) AS requestedfriendship,
                 (SELECT title FROM {artefact} WHERE artefacttype = \'introduction\' AND owner = u.id) AS introduction,
-                NULL AS reason
+                NULL AS message
                 FROM {usr} u
                 WHERE u.id IN (' . $userlist . ')
             UNION
@@ -918,37 +1047,39 @@ function get_users_data($userlist) {
 
     foreach ($data as &$record) {
         if (isset($record->introduction)) {
-            $record->introduction = str_shorten($record->introduction, 100, true);
+            $record->introduction = str_shorten_html($record->introduction, 100, true);
         }
 
         $record->messages = ($record->messages == 'allow' || $record->friend && $record->messages == 'friends' || $USER->get('admin')) ? 1 : 0;
+        $record->institutions = get_institution_string_for_user($record->id);
     }
 
-    if (!$data || !$views = get_views(array_keys($data), null, null)) {
+    if (!$data || !$getviews || !$views = get_views(array_keys($data), null, null)) {
         $views = array();
     }
 
-   $viewcount = array_map('count', $views);
-    // since php is so special and inconsistent, we can't use array_map for this because it breaks the top level indexes.
-    $cleanviews = array();
-    foreach ($views as $userindex => $viewarray) {
-        $cleanviews[$userindex] = array_slice($viewarray, 0, 5);
+    if ($getviews) {
+        $viewcount = array_map('count', $views);
+        // since php is so special and inconsistent, we can't use array_map for this because it breaks the top level indexes.
+        $cleanviews = array();
+        foreach ($views as $userindex => $viewarray) {
+            $cleanviews[$userindex] = array_slice($viewarray, 0, 5);
 
-        // Don't reveal any more about the view than necessary
-        foreach ($cleanviews as $userviews) {
-            foreach ($userviews as &$view) {
-               foreach (array_keys(get_object_vars($view)) as $key) {
-                    if ($key != 'id' && $key != 'title') {
-                        unset($view->$key);
+            // Don't reveal any more about the view than necessary
+            foreach ($cleanviews as $userviews) {
+                foreach ($userviews as &$view) {
+                    foreach (array_keys(get_object_vars($view)) as $key) {
+                        if ($key != 'id' && $key != 'title') {
+                            unset($view->$key);
+                        }
                     }
                 }
             }
         }
-
     }
 
     foreach ($data as $friend) {
-        if (isset($cleanviews[$friend->id])) {
+        if ($getviews && isset($cleanviews[$friend->id])) {
             $friend->views = $cleanviews[$friend->id];
         }
         if ($friend->pending) {
@@ -1016,6 +1147,52 @@ function get_users_data($userlist) {
     return $ordereddata;
 }
 
+function build_userlist_html(&$data, $page) {
+    if ($data['data']) {
+        $userlist = join(',', array_map(create_function('$u','return $u[\'id\'];'), $data['data']));
+        $userdata = get_users_data($userlist, $page == 'myfriends');
+    }
+    $smarty = smarty_core();
+    $smarty->assign('data', isset($userdata) ? $userdata : null);
+    $smarty->assign('page', $page);
+    $smarty->assign('query', $data['query']);
+    $data['tablerows'] = $smarty->fetch('user/userresults.tpl');
+    $pagination = build_pagination(array(
+        'id' => 'friendslist_pagination',
+        'url' => get_config('wwwroot') . 'user/' . $page . '.php?query=' . $data['query'],
+        'jsonscript' => 'json/friendsearch.php',
+        'datatable' => 'friendslist',
+        'count' => $data['count'],
+        'limit' => $data['limit'],
+        'offset' => $data['offset'],
+        'resultcounttextsingular' => get_string('user', 'group'),
+        'resultcounttextplural' => get_string('users', 'group'),
+        'extradata' => array('page' => $page),
+    ));
+    $data['pagination'] = $pagination['html'];
+    $data['pagination_js'] = $pagination['javascript'];
+}
+
+function get_institution_string_for_user($userid) {
+    static $institutions = null;
+    if (is_null($institutions)) {
+        $institutions = get_records_assoc('institution', '', '', '', 'name, displayname');
+    }
+
+    $user = new User;
+    $user->find_by_id($userid);
+
+    $userinstitutions = array();
+    foreach ($user->get('institutions') as $institution) {
+        $userinstitutions[] = $institutions[$institution->institution]->displayname;
+    }
+
+    if ($userinstitutions) {
+        return get_string('memberofinstitutions', 'mahara', join(', ', $userinstitutions));
+    }
+    return '';
+}
+
 function friends_control_sideblock($returnto='myfriends') {
     global $USER;
     $form = array(
@@ -1027,7 +1204,7 @@ function friends_control_sideblock($returnto='myfriends') {
             'friendscontrol' => array(
                 'type' => 'radio',
                 'defaultvalue' => $USER->get_account_preference('friendscontrol'),
-                'separator' => HTML_BR,
+                'separator' => '<br>',
                 'options' => array(
                     'nobody' => get_string('friendsnobody', 'account'),
                     'auth'   => get_string('friendsauth', 'account'),
@@ -1087,6 +1264,9 @@ function acceptfriend_submit(Pieform $form, $values) {
     insert_record('usr_friend', $f);
 
     db_commit();
+
+    handle_event('addfriend', array('user' => $f->usr2, 'friend' => $f->usr1));
+
     $SESSION->add_ok_msg(get_string('friendformacceptsuccess', 'group'));
     redirect('/user/view.php?id=' . $values['id']);
 }
@@ -1115,9 +1295,156 @@ function addfriend_submit(Pieform $form, $values) {
     $n->subject = get_string_from_language($lang, 'addedtofriendslistsubject', 'group');
     $n->message = get_string_from_language($lang, 'addedtofriendslistmessage', 'group', $displayname, $displayname);
 
+    require_once('activity.php');
     activity_occurred('maharamessage', $n);
+
+    handle_event('addfriend', array('user' => $f->usr2, 'friend' => $f->usr1));
+
     $SESSION->add_ok_msg(get_string('friendformaddsuccess', 'group', display_name($user)));
     redirect('/user/view.php?id=' . $values['id']);
 }
 
+/**
+ * Create user
+ *
+ * @param object $user stdclass or User object for the usr table
+ * @param array  $profile profile field/values to set
+ * @param string $institution Institution the user should joined to
+ * @param stdclass $remoteauth authinstance record for a remote authinstance
+ * @param string $remotename username on the remote site
+ * @return integer id of the new user
+ */
+function create_user($user, $profile=array(), $institution=null, $remoteauth=null, $remotename=null) {
+    db_begin();
+
+    if ($user instanceof User) {
+        $user->quota_init();
+        $user->commit();
+        $user = $user->to_stdclass();
+    }
+    else {
+        if (empty($user->quota)) {
+            $user->quota = get_config_plugin('artefact', 'file', 'defaultquota');
+        }
+        $user->id = insert_record('usr', $user, 'id', true);
+    }
+    // Bypass access check for 'copynewuser' institution/site views, because this user may not be logged in yet
+    $user->newuser = true;
+
+    if (isset($user->email) && $user->email != '') {
+        set_profile_field($user->id, 'email', $user->email);
+    }
+    if (isset($user->firstname) && $user->firstname != '') {
+        set_profile_field($user->id, 'firstname', $user->firstname);
+    }
+    if (isset($user->lastname) && $user->lastname != '') {
+        set_profile_field($user->id, 'lastname', $user->lastname);
+    }
+    foreach ($profile as $k => $v) {
+        if (in_array($k, array('firstname', 'lastname', 'email'))) {
+            continue;
+        }
+        set_profile_field($user->id, $k, $v);
+    }
+
+    if (!empty($institution) && $institution != 'mahara') {
+        if (is_string($institution)) {
+            $institution = new Institution($institution);
+        }
+        if ($institution->name != 'mahara') {
+            $institution->addUserAsMember($user); // uses $user->newuser
+        }
+    }
+
+    if (!empty($remoteauth) && $remoteauth->authname != 'internal') {
+        if (isset($remotename) && strlen($remotename) > 0) {
+            $un = $remotename;
+        }
+        else {
+            $un = $user->username;
+        }
+        delete_records('auth_remote_user', 'authinstance', $user->authinstance, 'remoteusername', $un);
+        insert_record('auth_remote_user', (object) array(
+            'authinstance'   => $user->authinstance,
+            'remoteusername' => $un,
+            'localusr'       => $user->id,
+        ));
+    }
+
+    // Copy site views to the new user's profile
+    $checkviewaccess = !$user->newuser;
+    $userobj = new User();
+    $userobj->find_by_id($user->id);
+    $userobj->copy_views(get_column('view', 'id', 'institution', 'mahara', 'copynewuser', 1), $checkviewaccess);
+
+    handle_event('createuser', $user);
+    db_commit();
+    return $user->id;
+}
+
+
+/**
+ * Given a user, makes sure they have been added to all groups that are marked 
+ * as ones that users should be auto-added to
+ *
+ * @param array $eventdata Event data passed from activity_occured, the key 'id' = userid
+ */
+function add_user_to_autoadd_groups($eventdata) {
+    require_once('group.php');
+    $userid = $eventdata['id'];
+    if ($autoaddgroups = get_column('group', 'id', 'usersautoadded', true)) {
+        foreach ($autoaddgroups as $groupid) {
+            if (!group_user_access($groupid, $userid)) {
+                group_add_user($groupid, $userid);
+            }
+        }
+    }
+}
+
+
+
+/**
+ * This function installs the site's default profile view
+ *
+ * @throws SystemException if the system profile view is already installed
+ */
+function install_system_profile_view() {
+    $viewid = get_field('view', 'id', 'owner', 0, 'type', 'profile');
+    if ($viewid) {
+        throw new SystemException('A system profile view already seems to be installed');
+    }
+    require_once(get_config('libroot') . 'view.php');
+    require_once(get_config('docroot') . 'blocktype/lib.php');
+    $view = View::create(array(
+        'type'        => 'profile',
+        'owner'       => 0,
+        'numcolumns'  => 2,
+        'ownerformat' => FORMAT_NAME_PREFERREDNAME,
+        'title'       => get_string('profileviewtitle', 'view'),
+        'description' => '',
+        'template'    => 1,
+    ));
+    $view->set_access(array(array(
+        'type' => 'loggedin'
+    )));
+    $blocktypes = array('myviews' => 1, 'mygroups' => 1, 'myfriends' => 2, 'wall' => 2);  // column ids
+    $installed = get_column_sql('SELECT name FROM {blocktype_installed} WHERE name IN (' . join(',', array_map('db_quote', array_keys($blocktypes))) . ')');
+    $weights = array(1 => 0, 2 => 0);
+    foreach (array_keys($blocktypes) as $blocktype) {
+        if (in_array($blocktype, $installed)) {
+            $weights[$blocktypes[$blocktype]]++;
+            $newblock = new BlockInstance(0, array(
+                'blocktype'  => $blocktype,
+                'title'      => get_string('title', 'blocktype.' . $blocktype),
+                'view'       => $view->get('id'),
+                'column'     => $blocktypes[$blocktype],
+                'order'      => $weights[$blocktypes[$blocktype]],
+            ));
+            $newblock->commit();
+        }
+    }
+    return $view->get('id');
+}
+
+
 ?>
