@@ -525,7 +525,7 @@ EOF;
         $smarty->assign('masqueradedetails', get_string('youaremasqueradingas', 'mahara', hsc(display_name($USER))));
         $smarty->assign('becomeyouagain',
             ' <a href="' . hsc($wwwroot) . 'admin/users/changeuser.php?restore=1">'
-            . get_string('becomeadminagain', 'admin', $USER->get('parentuser')->name)
+            . get_string('becomeadminagain', 'admin', hsc($USER->get('parentuser')->name))
             . '</a>');
     }
 
@@ -2534,9 +2534,9 @@ function display_cleaned_html($html, $filename, $params) {
     $smarty = smarty_core();
     $smarty->assign('params', $params);
     if ($params['owner']) {
-        $smarty->assign('htmlremovedmessage', get_string('htmlremovedmessage', 'artefact.file', $filename, get_config('wwwroot') . 'user/view.php?id=' . $params['owner'], display_name($params['owner'])));
+        $smarty->assign('htmlremovedmessage', get_string('htmlremovedmessage', 'artefact.file', hsc($filename), get_config('wwwroot') . 'user/view.php?id=' . (int) $params['owner'], hsc(display_name($params['owner']))));
     } else {
-        $smarty->assign('htmlremovedmessage', get_string('htmlremovedmessagenoowner', 'artefact.file', $filename));
+        $smarty->assign('htmlremovedmessage', get_string('htmlremovedmessagenoowner', 'artefact.file', hsc($filename)));
     }
     $smarty->assign('content', clean_html($html));
     $smarty->display('cleanedhtml.tpl');
